pub struct Chain<A, B> { /* private fields */ }
A lending iterator that iterates over the elements of two iterators in sequence.

This struct is created by the chain method on LendingIterator. See its documentation for more.