Struct gat_lending_iterator::Map
source · pub struct Map<I, F> { /* private fields */ }Expand description
A lending iterator that maps the elements of iter with f.
This struct is created by the map method on LendingIterator. See
its documentation for more.